/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.jmx.impl;

import javax.management.MBeanAttributeInfo;
import javax.management.modelmbean.ModelMBeanAttributeInfo;

import org.ow2.util.jmx.api.IMBeanAttribute;

/**
 * Implementations of this class can be added dynamically as attributes in a BaseModelMBeanExt.
 * @author missonng
 */
public abstract class AbstractMBeanAttribute implements IMBeanAttribute {
    /**
     * The MBeanAttributeInfo describing this attribute.
     */
    private ModelMBeanAttributeInfo info;

    /**
     * The AbstractMBeanAttribute constructor.
     * @param name The name of the attribute.
     * @param type The type or class name of the attribute.
     * @param description A human readable description of the attribute.
     * @param isReadable True if the attribute has a getter method, false otherwise.
     * @param isWritable True if the attribute has a setter method, false otherwise.
     * @param isIs True if this attribute has an "is" getter, false otherwise.
     */
    public AbstractMBeanAttribute(final String name, final String type, final String description,
            final boolean isReadable, final boolean isWritable, final boolean isIs) {
        this.info = new ModelMBeanAttributeInfo(name, type, description, isReadable, isWritable, isIs);
    }

    /**
     * Get the MBeanAttributeInfo describing this attribute.
     * @return The MBeanAttributeInfo describing this attribute.
     */
    public MBeanAttributeInfo getMBeanAttributeInfo() {
        return this.info;
    }
}
