/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.jmx.impl;

import javax.management.MBeanOperationInfo;
import javax.management.MBeanParameterInfo;

import org.ow2.util.jmx.api.IMBeanOperation;

/**
 * Implementations of this class can be added dynamically as operations in a BaseModelMBeanExt.
 * @author missonng
 */
public abstract class AbstractMBeanOperation implements IMBeanOperation {
    /**
     * The MBeanOperationInfo describing this operation.
     */
    private MBeanOperationInfo info;

    /**
     * The AbstractMBeanOperation constructor.
     * @param name The name of the method.
     * @param description A human readable description of the operation.
     * @param params MBeanParameterInfo objects describing the parameters(arguments) of the method.
     * This may be null with the same effect as a zero-length array.
     * @param type The type of the method's return value.
     * @param impact The impact of the method, one of INFO, ACTION, ACTION_INFO, UNKNOWN.
     */
    public AbstractMBeanOperation(final String name, final String description, final MBeanParameterInfo[] params,
            final String type, final int impact) {
        this.info = new MBeanOperationInfo(name, description, params, type, impact);
    }

    /**
     * Get the MBeanOperationInfo describing this operation.
     * @return The MBeanOperationInfo describing this operation.
     */
    public MBeanOperationInfo getMBeanOperationInfo() {
        return this.info;
    }
}
