/*
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.jmx.impl.activator;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.jmx.api.ICommonsModelerExtService;
import org.ow2.util.jmx.impl.CommonsModelerExtService;

/**
 * An {@link JMXActivator} is a {@link BundleActivator} that instantiates and starts an {@link CommonsModelerExtService} and register it
 * as an OSGI service under the name of the {@link ICommonsModelerExtService} class. When the bundle is stopped the service registration is
 * unregistered and the {@link CommonsModelerExtService} is stopped
 *
 * @author Loic Albertin
 */
public class JMXActivator implements BundleActivator {

    private ServiceRegistration<ICommonsModelerExtService> serviceRegistration;
    private CommonsModelerExtService modelerExtService;

    public void start(BundleContext context) throws Exception {
        modelerExtService = new CommonsModelerExtService();
        modelerExtService.start();
        serviceRegistration = context.registerService(ICommonsModelerExtService.class, modelerExtService, null);
    }

    public void stop(BundleContext context) throws Exception {
        serviceRegistration.unregister();
        modelerExtService.stop();
    }
}
